This glossary defines a number of terms commonly used across the documentation. For the definitions of framework components consult the API docs.

* **AEA (Autonomous Economic Agent)**: An AEA is "an intelligent agent acting on an owner's behalf, with limited or no interference, and whose goal is to generate economic value to its owner". AEAs are a special type of agent. [<a href="../index">more</a>]

* **Software Agent**: a software agent is a computer program that acts on behalf of an entity (e.g. individual, organisation, business). [<a href="https://en.wikipedia.org/wiki/Software_agent" target="_blank">more</a>]

* **sOEF (Simple Open Economic Framework)**: The simple-OEF, or sOEF, is a search and discovery service for autonomous economic agents. [<a href="../simple-oef">more</a>]

* **ACN (Agent Communication Network)**: The ACN is a peer-to-peer communication network for autonomous economic agents. [<a href="../acn">more</a>]